*{padding:0;margin:0}html,body{min-height:100%!important;height:100%;overflow:hidden}#container{width:100%;height:100%;overflow:hidden;position:relative}.highlighted-line{background-color:#add8e6;width:5px!important;margin-left:3px}
